<?php

namespace Drupal\commerce_ups_fulfillment\Controller;
///*-*/

use Drupal\commerce_shipping\Entity\ShipmentInterface;
use Drupal\commerce_shipping\Entity\ShippingMethod;
use Drupal\commerce_ups_fulfillment\UPSFulfillmentSdk;
use Drupal\commerce_ups_fulfillment\UPSFulfillmentSdkFactory;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

class UPSFulfillmentController extends ControllerBase {

  public function __construct(UPSFulfillmentSdkFactory $upsSdkFactory) {
    $this->upsSdkFactory = $upsSdkFactory;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('commerce_ups.ups_fulfillment_sdk_factory')
    );
  }

  public function createShipment(ShipmentInterface $shipment): array {

    // Load all shipping methods.
    $shipping_methods = ShippingMethod::loadMultiple();
    $config = [];
    $count = 0;

    foreach ($shipping_methods as $method_id => $method) {
      $plugin = $method->getPlugin();

      if (!$method->isEnabled()) {
        continue;
      }

      // Check if the plugin ID is 'ups'.
      if ($plugin->getPluginId() === 'ups') {
        $config = $plugin->getConfiguration();
        $count++;
      }
    }

    // If no enabled plugins are found, search for disabled plugins (GTCC workaround)
    if ($count === 0) {
      foreach ($shipping_methods as $method_id => $method) {
        $plugin = $method->getPlugin();

        // Check if the plugin ID is 'ups'.
        if ($plugin->getPluginId() === 'ups') {
          $config = $plugin->getConfiguration();
        }
      }
    }

    /** @var UPSFulfillmentSdk $upsSdk */
    $upsSdk = $this->upsSdkFactory->get($config['api_information']);
    $upsSdk->setShipment($shipment);
    return $upsSdk->createShipment();

  }

  public function configPage() {
    return [
      '#markup' => $this->t('UPS Fulfillment settings go here.'),
    ];
  }

}